@@ -297,6 +297,15 @@ public interface UserManager {
 	 * @throws UserRetrievalFault
 	 */
 	List<GCubeMembershipRequest> listMembershipRequestsByGroup(long groupId) throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault;
+	/**
+	 * 
+	 * @param groupId the LR groupId
+	 * @return the list of {@link GCubeMembershipRequest} with status requested and users given the LR GroupId @see {@link MembershipRequestStatus}  
+	 * @throws UserManagementSystemException
+	 * @throws GroupRetrievalFault
+	 * @throws UserRetrievalFault
+	 */
+	List<GCubeMembershipRequest> listPendingMembershipRequestsByGroup(long groupId) throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault;
 	/**
 	 * 
 	 * @param requestId
